@@ -62,9 +62,8 @@
   (and evil-textobj-tree-sitter--can-use-builtin-treesit
        (let ((major-mode-name (symbol-name major-mode)))
          (or (string-suffix-p "-ts-mode" major-mode-name)
-             (and (boundp 'rust-mode-treesitter-derive)
-                  rust-mode-treesitter-derive
-                  (string= "rustic-mode" major-mode-name))))))
+             (and (bound-and-true-p rust-mode-treesitter-derive)
+                  (derived-mode-p 'rust-mode))))))
 
 (defun evil-textobj-tree-sitter--get-queries-dir ()
   "Get the queries directory.
@@ -88,8 +87,8 @@ Currently treesit queries are different from queries for elisp-tree-sitter."
                           (c++-ts-mode . "cpp")
                           (c-mode . "c")
                           (c-ts-mode . "c")
-                          (csharp-mode . "csharp")
-                          (csharp-ts-mode . "csharp")
+                          (csharp-mode . "c_sharp")
+                          (csharp-ts-mode . "c-sharp")
                           (elixir-mode . "elixir")
                           (elixir-ts-mode . "elixir")
                           (elm-mode . "elm")
